@@ -181,14 +181,14 @@ class GroCropClient(object):
         region_id = get_region_id(region_name, source_name)
         crop = is_corn_or_soybeans(item_name)
         if crop == ItemNameCategoryList.CORN.value:
-            yield_dict = self._client.get_area_weighted_series(AreaWeightingSeriesList.CORN_YIELD.value, ['NASS Corn (US only)'], region_id, latest_date_only)
+            yield_dict = self._client.get_area_weighted_series(AreaWeightingSeriesList.CORN_YIELD.value, ['NASS Corn (US only)'], region_id, latest_date_only=latest_date_only)
         elif crop == ItemNameCategoryList.SOYBEANS.value:
-            yield_dict = self._client.get_area_weighted_series(AreaWeightingSeriesList.SOYBEANS_YIELD.value, ['NASS Soybeans (US only)'], region_id, latest_date_only)
+            yield_dict = self._client.get_area_weighted_series(AreaWeightingSeriesList.SOYBEANS_YIELD.value, ['NASS Soybeans (US only)'], region_id, latest_date_only=latest_date_only)
  
         return pd.DataFrame({'Yield': yield_dict.values()}, yield_dict.keys())
     
 
-    def get_crop_budget_price_model(self, item_name: str, region_name: str, source_name: str, latest_date_only=False) -> pd.DataFrame:
+    def get_crop_budget_price(self, item_name: str, region_name: str, source_name: str, latest_date_only=False) -> pd.DataFrame:
         """
         Get the DTN Price ($/bu) values for the given item and region combination. If `latest_date_only` is True, only get the latest Price value.
         The price value returned for each date is an average of the district region values within the requested region.
@@ -212,9 +212,9 @@ class GroCropClient(object):
         region_id = get_region_id(region_name, source_name)
         crop = is_corn_or_soybeans(item_name)
         if crop == ItemNameCategoryList.CORN.value:
-            price_dict = self._client.get_area_weighted_series(AreaWeightingSeriesList.CORN_PRICE.value, ['AVERAGE'], region_id,latest_date_only)
+            price_dict = self._client.get_area_weighted_series(AreaWeightingSeriesList.CORN_PRICE.value, ['AVERAGE'], region_id,latest_date_only=latest_date_only)
         elif crop == ItemNameCategoryList.SOYBEANS.value:
-            price_dict = self._client.get_area_weighted_series(AreaWeightingSeriesList.SOYBEANS_PRICE.value, ['AVERAGE'], region_id, latest_date_only)
+            price_dict = self._client.get_area_weighted_series(AreaWeightingSeriesList.SOYBEANS_PRICE.value, ['AVERAGE'], region_id, latest_date_only=latest_date_only)
 
         return pd.DataFrame({'Price': price_dict.values()}, price_dict.keys())
     # END OF CROP BUDGET functions
